@@ -31,21 +31,21 @@ from dataclasses import (
     fields,
 )
 from datetime import date, datetime
-from deprecated import deprecated
 from enum import Enum
 import json
+import mimetypes
 from pathlib import Path
 from typing import Any, Dict, List
 from typing import Callable, Optional, Tuple, TypeVar, Union
 import struct
 import warnings
 
-import mimetypes
 from dataclasses_json import dataclass_json as dataclass_json
 from dataclasses_json.core import _decode_dataclass
 from dataclasses_json.core import _ExtendedEncoder as JsonEncoder
+from deprecated import deprecated
 
-__version__ = "1.13.5"
+__version__ = "1.13.9"
 
 """
 About the GLTF2 file format:
@@ -282,7 +282,7 @@ class Attributes:
             setattr(self, key, value)
 
     def __repr__(self):
-        return self.__class__.__qualname__ + f'(' + ', '.join([f"{f}={v}" for f, v in self.__dict__.items()]) + ')'
+        return self.__class__.__qualname__ + '(' + ', '.join([f"{f}={v}" for f, v in self.__dict__.items()]) + ')'
 
     def to_json(self, *args, **kwargs):
         # Attributes objects can have custom attrs, so use our own json conversion methods.
@@ -439,7 +439,7 @@ class NormalMaterialTexture(Property):
 @dataclass_json
 @dataclass
 class PbrMetallicRoughness(Property):
-    baseColorFactor: Optional[List[float]] = field(default_factory=lambda: [1.0, 1.0, 1.0])
+    baseColorFactor: Optional[List[float]] = field(default_factory=lambda: [1.0, 1.0, 1.0, 1.0])
     metallicFactor: Optional[float] = 1.0
     roughnessFactor: Optional[float] = 1.0
     baseColorTexture: Optional[TextureInfo] = None
@@ -638,7 +638,8 @@ class GLTF2(Property):
         def update_obj(title, obj):
             if obj:
                 if obj.bufferView == buffer_view_id:
-                    warnings.warn(f"Removing bufferView {buffer_view_id} but {title}.bufferView still points to it. This may corrupt the GLTF.")
+                    warnings.warn(f"Removing bufferView {buffer_view_id} but "
+                                  f"{title}.bufferView still points to it. This may corrupt the GLTF.")
                 if obj.bufferView >= buffer_view_id:
                     obj.bufferView -= 1
             else:
@@ -730,11 +731,11 @@ class GLTF2(Property):
                             image.uri = f'data:{mime};base64,{encoded_string}'
                 elif image.bufferView:
                     # TODO: remove bufferView from GLTF when create images or datauris from buffer data
-                    warnings.warn("pygltflib currently does not remove image data from the buffer when converting to data uri."
+                    warnings.warn("pygltflib currently does not remove image data "
+                                  "from the buffer when converting to data uri."
                                   "Please open an issue at https://gitlab.com/dodgyville/pygltflib/issues")
                     data = self.binary_blob()
                     bufferView = self.bufferViews[image.bufferView]
-                    buffer = self.buffers[bufferView.buffer]
                     image_data = data[bufferView.byteOffset:bufferView.byteOffset + bufferView.byteLength]
                     encoded_string = str(base64.b64encode(image_data).decode('utf-8'))
                     image.uri = f'data:{image.mimeType};base64,{encoded_string}'
@@ -751,7 +752,7 @@ class GLTF2(Property):
                 continue
             elif image_format == ImageFormat.FILE:   # convert to images
                 file_name = self.export_image_to_file(image_index, override)
-                if file_name: # replace data uri with pointer to file
+                if file_name:  # replace data uri with pointer to file
                     image.uri = file_name
 
     def convert_buffers(self, buffer_format, override=False):
@@ -836,14 +837,12 @@ class GLTF2(Property):
     def from_json(cls: A,
                   s: str,
                   *,
-                  encoding=None,
                   parse_float=None,
                   parse_int=None,
                   parse_constant=None,
                   infer_missing=False,
                   **kw) -> A:
         init_kwargs = json.loads(s,
-                                 encoding=encoding,
                                  parse_float=parse_float,
                                  parse_int=parse_int,
                                  parse_constant=parse_constant,
@@ -978,9 +977,7 @@ class GLTF2(Property):
         return obj
 
     @classmethod
-    def load_binary(cls, fname):
-        with open(fname, "rb") as f:
-            data = f.read()
+    def load_from_bytes(cls, data):
         magic = struct.unpack("<BBBB", data[:4])
         version, length = struct.unpack("<II", data[4:12])
         if bytearray(magic) != MAGIC:
@@ -1010,6 +1007,17 @@ class GLTF2(Property):
             i += 1
         return obj
 
+    @classmethod
+    def load_binary(cls, fname):
+        with open(fname, "rb") as f:
+            data = f.read()
+        return cls.load_from_bytes(data)
+
+    @classmethod
+    def load_binary_from_file_object(cls, f):
+        data = f.read()
+        return cls.load_from_bytes(data)
+
     @classmethod
     def load(cls, fname):
         path = Path(fname)
